"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.makeLogger = void 0;
const readline = require("readline");
let previousProgress = undefined;
function makeLogger({ env, stdout, stderr, }) {
    const NO_COLOR = "NO_COLOR" in env;
    const handleColor = (string) => 
    // eslint-disable-next-line no-control-regex
    NO_COLOR ? string.replace(/\x1B\[\dm/g, "") : string;
    return {
        log(message) {
            previousProgress = undefined;
            stdout.write(handleColor(message) + "\n");
        },
        error(message) {
            previousProgress = undefined;
            stderr.write(handleColor(message) + "\n");
        },
        /* istanbul ignore next */
        progress(passedMessage) {
            const message = handleColor(passedMessage);
            if (previousProgress !== undefined) {
                readline.moveCursor(stdout, 0, -previousProgress);
            }
            previousProgress = message.split("\n").length;
            stdout.write(message + "\n");
        },
    };
}
exports.makeLogger = makeLogger;
