#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const download_1 = require("./commands/download");
const help_1 = require("./commands/help");
const init_1 = require("./commands/init");
const postinstall_1 = require("./commands/postinstall");
const validate_1 = require("./commands/validate");
const logger_1 = require("./helpers/logger");
async function run(argv, cwd, env, logger) {
    // So far no command takes any further arguments.
    // Let each command handle this when needed.
    if (argv.length > 1) {
        logger.error(`Expected a single argument but got: ${argv.slice(1).join(" ")}`);
        return 1;
    }
    switch (argv[0]) {
        case undefined:
        case "-h":
        case "-help":
        case "--help":
        case "help":
            logger.log(help_1.default(cwd, env));
            return 0;
        case "init":
            return await init_1.default(cwd, logger);
        case "validate":
            return validate_1.default(cwd, env, logger);
        case "download": {
            const result = await download_1.default(cwd, env, logger);
            switch (result.tag) {
                case "Exit":
                    return result.statusCode;
                case "Success":
                    return 0;
            }
        }
        case "postinstall":
            return await postinstall_1.default(cwd, env, logger);
        default:
            logger.error(`Unknown command: ${argv[0]}`);
            return 1;
    }
}
function elmToolingCli(args, 
/* istanbul ignore next */
{ cwd, env, stdout, stderr } = {
    cwd: process.cwd(),
    env: process.env,
    stdin: process.stdin,
    stdout: process.stdout,
    stderr: process.stderr,
}) {
    return run(args, cwd, env, logger_1.makeLogger({ env, stdout, stderr }));
}
module.exports = elmToolingCli;
/* istanbul ignore if */
if (require.main === module) {
    elmToolingCli(process.argv.slice(2)).then((exitCode) => {
        process.exit(exitCode);
    }, (error) => {
        process.stderr.write(`Unexpected error:\n${error.stack || error.message}\n`);
        process.exit(1);
    });
}
